package com.cweb.controller;

import com.hfkj.common.utils.RedisUtil;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.entity.CmsContent;
import com.hfkj.model.ResponseData;
import com.hfkj.service.CmsContentService;
import com.hfkj.service.impl.CmsContentServiceImpl;
import com.hfkj.sysenum.cms.CmsStatusEnum;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @className: CmsController
 * @author: HuRui
 * @date: 2024/9/24
 **/
@Controller
@RequestMapping(value = "/cms")
@Api(value = "CMS")
public class CmsController {
    private static Logger log = LoggerFactory.getLogger(CmsController.class);
    @Resource
    private CmsContentService cmsContentService;
    @Resource
    private RedisUtil redisUtil;

    @RequestMapping(value="/query",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询列表")
    public ResponseData query(@RequestParam(name = "type", required = true) Integer type) {
        try {
            // 读取缓存
            Object cacheObj = redisUtil.hget(CmsContentServiceImpl.CACHE_CMS_ONLINE, "" + type);
            if (cacheObj != null) {
                return ResponseMsgUtil.success(cacheObj);
            }
            Map<String,Object> param = new HashMap<>();
            param.put("type", type);
            param.put("status", CmsStatusEnum.status2.getStatus());
            List<CmsContent> list = cmsContentService.getList(param);
            // 缓存
            redisUtil.hset(CmsContentServiceImpl.CACHE_CMS_ONLINE, "" + type, list);
            return ResponseMsgUtil.success(list);
        } catch (Exception e) {
            return ResponseMsgUtil.exception(e);
        }
    }
}
